<h6 align="left">
    <img src="https://cdnquakingaspen.s3.eu-central-1.amazonaws.com/quaking+aspen+logo+teal+full-02.png"  />
</h6>

# flask_jwt_auth
[Introduction](#Introduction)\
[Getting Started](#Started)\
[Example](#Example)\
[Contributors](#Contributors)\
[License](#License)
<h2 id="Introduction">Introduction</h2>
This module contains a simple class to implement authentication and authorization in a Flask app using JSON Web Token (JWT)
 
<h2 id="Started">Getting Started</h2>
In order to install, open the command prompt and type ✌️:

```
pip install flask_jwt_auth
```

In order to import:
```
from flask_jwt_auth import AuthFilters
```

<h2 id="">Contributors</h2>

This project exists thanks to all the people who contribute. [[Contribute](CONTRIBUTING.md)].
<a href="https://github.com/Quakingaspen-codehub/flask_jwt_auth/graphs/contributors">
""
</a>

<h2 id="License">License</h2>

This library is licensed under the MIT License - see the [LICENSE.md](LICENSE) file for details.
